;******************************************************************************
;
;    This program is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program; if not, write to the Free Software
;    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
;
;    I (Simon Wood) can be contacted via email - unilink@mungewell.org
;    or via post - 14 Kirklands Close, Baildon, West Yorkshire, England.
;
;******************************************************************************
;	Additional Info - Release version  1.8T_05
;		Modified Version : GNUnilink for MDX-5V101R
;			"Released under the GPL license, 
;					(c) H "Turboh" Ishimoto, 2004,2005"
;					   Email: ishimoto@bea.hi-ho.ne.jp
;******************************************************************************
;;-- Interrupt Procedures			Jan. 12 2004 (T)
;;-- NOTE
;; Interrupt is used to invoke count up playing time on the display,
;; It's period is 1.0sec.
;;	OSC Frequency is limited to 20MHz.
;;	set TMR1(TMR1H and TMR1L), and SoftwareCounter "Int1secData".
;;

; Interrupt Vector - used to process serial data
	ORG	_IntVector

	movwf	w_store				; store w register
	swapf	STATUS,W
	bcf	STATUS,RP0
	movwf	status_store			; store status register

	call	Int_Reset

;;--- Interrupt procedure		Jan. 25 2004 (T)
					;; Sleeping flag checking
	movf	Sleeping, 0		;; Sleeping -> W
	xorlw	0x01			;; check 0x01?
	btfss	STATUS, Z		;;
	goto	Tmr1_Int		;;  (not Sleeping)

					;; case Sleeping
	btfss	INTCON, INTF		;; check RB0/INT flag
	goto	Tmr1_Int		;; case Not RB0/INT

	movlw	0x02			;; case RB0/INT
	movwf	Sleeping		;; set Sleeping=2 (goto Resume)
	goto	Int1sec_Exit		;; Exit Interrupt

Tmr1_Int:
	btfss	PIR1, TMR1IF		;; Check TMR1 Int?
	goto	Int1sec_Exit		;; case Not TMR1 Int, Exit.

	bcf	PIR1, TMR1IF		;; case TMR1 Int, clear overflow flag

	movlw	TMR1H_SetData		;; set TMR1H initial
	movwf	TMR1H

	movlw	TMR1L_SetData		;; set TMR1H initial
	movwf	TMR1L
	
	decfsz	Int1sec_Count, 1	;; decrement software counter
	goto	Int1sec_Exit		;; if Zero, skip to "Int1sec_Exit"
	goto	Int1sec_Exec

Int1sec_Exec:				;; Setting Int1secON counter
	movlw	Int1sec_Data		;; 
	movwf	Int1sec_Count

	call	Countup			;; <Procedure You Want to Execute>
	bsf	Int1secON, 0		;; 

Int1sec_Exit:
	call	Int_Enaset

	bcf	STATUS, RP0		;; force setting to switch Bank0.
	swapf	status_store,W		; restore registers
	movwf	STATUS
	swapf	w_store,F
	swapf	w_store,W    

	RETFIE				; re enable interrupts

;******************************************************************************
;; --------End of interrupt.asm
